@@ -12,7 +12,8 @@ pub enum ErrorCode {
     InvalidTokenManagerTokenAccount,
     #[msg("Token account not owned by issuer")]
     InvalidIssuerTokenAccount,
-    
+    #[msg("Max invalidators reached")]
+    MaximumInvalidatorsReached,
     #[msg("Token account not owned by recipient")]
     InvalidRecipientTokenAccount,
     #[msg("Token account not owned by invalidator")]
@@ -53,4 +54,4 @@ pub enum ErrorCode {
     InvalidReceiptMint,
     #[msg("Invalid current holder token account")]
     InvalidCurrentTokenAccount,
-}
\ No newline at end of file
+}
