@@ -1,6 +1,6 @@
 use {
-    crate::{state::*, errors::ErrorCode},
-    anchor_lang::{prelude::*},
+    crate::{errors::ErrorCode, state::*},
+    anchor_lang::prelude::*,
 };
 
 #[derive(Accounts)]
@@ -31,5 +31,5 @@ pub fn handler(ctx: Context<CreateTransferReceiptCtx>, target: Pubkey) -> Result
     transfer_receipt.mint_count = ctx.accounts.token_manager.count;
     transfer_receipt.token_manager = ctx.accounts.token_manager.key();
     transfer_receipt.target = target;
-    return Ok(())
-}
\ No newline at end of file
+    Ok(())
+}
