@@ -1,7 +1,7 @@
 use {
-    crate::{state::*, errors::ErrorCode},
-    anchor_lang::{prelude::*},
-    anchor_spl::{token::{self, Token, TokenAccount, Transfer}}
+    crate::{errors::ErrorCode, state::*},
+    anchor_lang::prelude::*,
+    anchor_spl::token::{self, Token, TokenAccount, Transfer},
 };
 
 #[derive(AnchorSerialize, AnchorDeserialize)]
@@ -14,15 +14,15 @@ pub struct IssueIx {
 #[derive(Accounts)]
 #[instruction(ix: IssueIx)]
 pub struct IssueCtx<'info> {
-    #[account(mut)]
+    #[account(mut, constraint = token_manager.state == TokenManagerState::Initialized as u8 @ ErrorCode::InvalidTokenManagerState)]
     token_manager: Box<Account<'info, TokenManager>>,
     #[account(mut, constraint = token_manager_token_account.owner == token_manager.key() @ ErrorCode::InvalidTokenManagerTokenAccount)]
     token_manager_token_account: Box<Account<'info, TokenAccount>>,
 
     // issuer
-    #[account(mut, constraint = issuer.key() == token_manager.issuer @ ErrorCode::InvalidIssuer)]
+    #[account(constraint = issuer.key() == token_manager.issuer @ ErrorCode::InvalidIssuer)]
     issuer: Signer<'info>,
-    #[account(mut, constraint = issuer_token_account.owner == issuer.key() @ ErrorCode::InvalidIssuerTokenAccount)]
+    #[account(mut, constraint = issuer_token_account.mint == token_manager.mint && issuer_token_account.owner == issuer.key() @ ErrorCode::InvalidIssuerTokenAccount)]
     issuer_token_account: Box<Account<'info, TokenAccount>>,
 
     // other
@@ -33,19 +33,15 @@ pub struct IssueCtx<'info> {
 }
 
 pub fn handler(ctx: Context<IssueCtx>, ix: IssueIx) -> Result<()> {
-    if ix.kind != TokenManagerKind::Managed as u8
-        && ix.kind != TokenManagerKind::Unmanaged as u8
-        && ix.kind != TokenManagerKind::Edition as u8 {
+    if ix.kind != TokenManagerKind::Managed as u8 && ix.kind != TokenManagerKind::Unmanaged as u8 && ix.kind != TokenManagerKind::Edition as u8 {
         return Err(error!(ErrorCode::InvalidTokenManagerKind));
     }
-    if ix.invalidation_type != InvalidationType::Return as u8
-        && ix.invalidation_type != InvalidationType::Invalidate as u8 {
+    if ix.invalidation_type != InvalidationType::Return as u8 && ix.invalidation_type != InvalidationType::Invalidate as u8 {
         return Err(error!(ErrorCode::InvalidInvalidationType));
     }
 
     // set token manager data
     let token_manager = &mut ctx.accounts.token_manager;
-    token_manager.mint = token_manager.mint;
     token_manager.amount = ix.amount;
     token_manager.issuer = ctx.accounts.issuer.key();
     token_manager.kind = ix.kind;
@@ -63,5 +59,5 @@ pub fn handler(ctx: Context<IssueCtx>, ix: IssueIx) -> Result<()> {
     let cpi_program = ctx.accounts.token_program.to_account_info();
     let cpi_context = CpiContext::new(cpi_program, cpi_accounts);
     token::transfer(cpi_context, token_manager.amount)?;
-    return Ok(())
-}
\ No newline at end of file
+    Ok(())
+}
